# PLN-{{ACID}}: {{TITLE}}

**Applies to:** {{PREFIX}} project
**Last updated:** {{DATE}}
**Last reviewed:** {{DATE}}
**Status:** Draft

---

## What Is It?

<description>

---

## Goals

- Goal 1

## Milestones

| # | Milestone | Target Date | Status |
|---|-----------|-------------|--------|
| 1 | — | — | Pending |

---

## Change History

| Date | Change | By |
|------|--------|----|
| {{DATE}} | Initial version | — |
